hyperdriver

Module body

Arnold is a Body builder, useful for wrapping different potential bodies for sending responses or requests. For reading incoming requests, defer to hyper::body::Incoming.

Re-exports

Structs

Traits

  • Extension trait to help clone a request that contains a Body.

Type Aliases