#[non_exhaustive]pub enum ConnectionError {
Connecting(Box<dyn Error + Send + Sync + 'static>),
Handshake(Box<dyn Error + Send + Sync + 'static>),
Canceled(Error),
Closed(Error),
Timeout,
InvalidUri(UriError),
}Available on crate feature
client only.Expand description
Error returned when a connection could not be established.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Connecting(Box<dyn Error + Send + Sync + 'static>)
Error connecting to the remote host via the transport
Handshake(Box<dyn Error + Send + Sync + 'static>)
Error completing the handshake.
Canceled(Error)
Connection was cancelled, probably because another one was established.
Closed(Error)
Connection was closed.
Timeout
Connection timed out.
InvalidUri(UriError)
Invalid URI for the connection