Enum hyperdriver::client::conn::connection::UriError
source · pub enum UriError {
InvalidUri(InvalidUri),
MissingScheme(Uri),
}Available on crate feature
client only.Expand description
The URI used for connecting to a server is invalid.
Usually, this means that the URI is missing a scheme or authority, but it can also mean that the connection string could not be parsed.
Variants
InvalidUri(InvalidUri)
The connection string could not be parsed.
MissingScheme(Uri)
The URI is missing a scheme.