#[non_exhaustive]pub enum UriError {
InvalidUri(InvalidUri),
MissingScheme(Uri),
}Available on crate feature
client only.Expand description
The URI used for connecting to a server is invalid.
Usually, this means that the URI is missing a scheme or authority, but it can also mean that the connection string could not be parsed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidUri(InvalidUri)
The connection string could not be parsed.
MissingScheme(Uri)
The URI is missing a scheme.