Struct hyperdriver::client::ClientService
source · pub struct ClientService<T, P, BOut = Body>{ /* private fields */ }client only.Expand description
A client which provides a simple HTTP tower::Service.
Client Services combine a transport (e.g. TCP) and a protocol (e.g. HTTP)
to provide a tower::Service that can be used to make requests to a server. Optionally, a connection
pool can be configured so that individual connections can be reused.
To use a client service, you must first poll the service to readiness with Service::poll_ready,
and then make the request with Service::call. This can be simplified with the tower::ServiceExt
which provides a Service::oneshot method that combines these two steps into a single future.
Implementations
sourceimpl<P, T, BOut> ClientService<T, P, BOut>
impl<P, T, BOut> ClientService<T, P, BOut>
sourcepub fn new(transport: T, protocol: P, pool: Config) -> Self
pub fn new(transport: T, protocol: P, pool: Config) -> Self
Create a new client with the given transport, protocol, and pool configuration.
sourcepub fn without_pool(self) -> Self
pub fn without_pool(self) -> Self
Disable connection pooling for this client.
sourceimpl ClientService<TlsTransport<TcpTransport>, HttpConnectionBuilder, Body>
impl ClientService<TlsTransport<TcpTransport>, HttpConnectionBuilder, Body>
sourcepub fn new_tcp_http() -> Self
pub fn new_tcp_http() -> Self
Create a new client with the default configuration for making requests over TCP connections using the HTTP protocol.
When the tls feature is enabled, this will also add support for tls when
using the https scheme, with a default TLS configuration that will rely
on the system’s certificate store.
sourceimpl<P, C, T, BOut> ClientService<T, P, BOut>
impl<P, C, T, BOut> ClientService<T, P, BOut>