pub struct ConnectionPoolService<T, P, S, BIn = Body, K = UriKey>{ /* private fields */ }client only.Expand description
A service which gets a connection from a possible connection pool and passes it to an inner service to execute that request.
This service will accept http::Request objects, but expects the inner service
to accept ExecuteRequest objects, which bundle the connection with the request.
The simplest interior service is crate::service::RequestExecutor, which will execute the request
on the connection and return the response.
Implementations
sourceimpl<T, P, S, BIn, K> ConnectionPoolService<T, P, S, BIn, K>
impl<T, P, S, BIn, K> ConnectionPoolService<T, P, S, BIn, K>
sourcepub fn new(transport: T, protocol: P, service: S, pool: Config) -> Self
pub fn new(transport: T, protocol: P, service: S, pool: Config) -> Self
Create a new client with the given transport, protocol, and pool configuration.
sourcepub fn without_pool(self) -> Self
pub fn without_pool(self) -> Self
Disable connection pooling for this client.
sourceimpl ConnectionPoolService<TlsTransport<TcpTransport>, HttpConnectionBuilder<Body>, RequestExecutor<HttpConnection<Body>, Body>, Body>
impl ConnectionPoolService<TlsTransport<TcpTransport>, HttpConnectionBuilder<Body>, RequestExecutor<HttpConnection<Body>, Body>, Body>
sourcepub fn new_tcp_http() -> Self
pub fn new_tcp_http() -> Self
Create a new client with the default configuration for making requests over TCP connections using the HTTP protocol.
When the tls feature is enabled, this will also add support for tls when
using the https scheme, with a default TLS configuration that will rely
on the system’s certificate store.
sourceimpl<P, C, T, S, K, BIn, BOut> ConnectionPoolService<T, P, S, BIn, K>where
C: Connection<BIn, ResBody = BOut> + PoolableConnection,
P: Protocol<T::IO, BIn, Connection = C, Error = ConnectionError> + Clone + Send + Sync + 'static,
T: Transport + 'static,
T::IO: PoolableStream + Unpin,
S: Service<ExecuteRequest<C, BIn>, Response = Response<BOut>> + Clone + Send + 'static,
S::Error: Into<Error>,
BIn: Body + Unpin + Send + 'static,
<BIn as Body>::Data: Send,
<BIn as Body>::Error: Into<Box<dyn Error + Send + Sync>>,
BOut: Body + Unpin + 'static,
<<T as Transport>::IO as HasConnectionInfo>::Addr: Send,
K: Key,
impl<P, C, T, S, K, BIn, BOut> ConnectionPoolService<T, P, S, BIn, K>where
C: Connection<BIn, ResBody = BOut> + PoolableConnection,
P: Protocol<T::IO, BIn, Connection = C, Error = ConnectionError> + Clone + Send + Sync + 'static,
T: Transport + 'static,
T::IO: PoolableStream + Unpin,
S: Service<ExecuteRequest<C, BIn>, Response = Response<BOut>> + Clone + Send + 'static,
S::Error: Into<Error>,
BIn: Body + Unpin + Send + 'static,
<BIn as Body>::Data: Send,
<BIn as Body>::Error: Into<Box<dyn Error + Send + Sync>>,
BOut: Body + Unpin + 'static,
<<T as Transport>::IO as HasConnectionInfo>::Addr: Send,
K: Key,