Module hyperdriver::discovery
source · Expand description
Support for service discovery in process via a registry using unix domain sockets.
Structs
- An error occured binding this service to the specified name.
- A scheme for the
grpcprotocol, which uses the first path component to determine which service to call. - Configuration for the service registry.
- A connection transport which uses roomservice’s internal service registry.
- Maintains the set of available services, and the connection configurations for those services.
- A scheme for the
svcprotocol, which uses the host to determine which service to call. - A builder for creating a
RegistryTransport, by adding custom schemes.
Enums
- An error occured while connecting to a service.
- Service discovery mechanism for services registered.
Traits
- A trait for extracting the service name from a request.
Type Aliases
- Service Registry client which will connect to internal services.