Struct hyperdriver::discovery::GrpcScheme

source ·
pub struct GrpcScheme(/* private fields */);
A scheme for the grpc protocol, which uses the first path component to determine which service to call.

This is how the gRPC protocol works natively.

Implementations

source

impl GrpcScheme

source

pub fn new<S>(scheme: S) -> Self
where S: Into<String>,

Create a new GrpcScheme with the given scheme.