Module conn

Available on crate feature server only.
Server-side connection builders for the HTTP2 protocol and the HTTP1 protocol.

Modules

auto
HTTP connection builder with automatic protocol detection.
http1
HTTP/1 Server Connections
http2
HTTP/2 Server Connections
tlstls
Implementation of a server side TLS stream on top of tokio_rustls which additionally provides connection information after the handshake has been completed.

Structs

AcceptOne
A future that resolves to a single connection
Acceptor
Accept incoming connections for streams which might be wrapped in TLS. Use Acceptor::with_tls to enable TLS.
AcceptorCorestream
A stream of incoming connections.
ConnectionWithInfo
Interior service which adds connection information to the request extensions.
MakeServiceConnectionInfoLayer
A middleware which adds connection information to the request extensions.
MakeServiceConnectionInfoService
A service which adds connection information to the request extensions.
Stream
Dispatching wrapper for potential stream connection types for servers

Enums

ConnectionError
Errors that can occur when handling connections.

Traits

Accept
An async generator of new connections
AcceptExt
Extension trait for Accept
Connection
A connection that can be gracefully shutdown.