Struct hyperdriver::service::AdaptCustomBodyService

source ·
pub struct AdaptCustomBodyService<BIn, BOut, S> { /* private fields */ }
Adapt a service to use custom body types internally, while still accepting and returning Body as the outer body type.

This is useful when interfacing with other libraries which want to bring their own body types, but you want to use Body as the outer body type and use hyperdriver::Server.

Implementations

source

impl<BIn, BOut, S> AdaptCustomBodyService<BIn, BOut, S>

source

pub fn new(inner: S) -> Self

Create a new AdaptCustomBodyService.