OptionService

Struct OptionService 

pub struct OptionService<M, S> { /* private fields */ }
A middleware for an optional layer with merged error types.

The tower::util::Either middleware converts errors to BoxError, which can make it difficult to return to a concrete error type. This middleware allows the inner service to return a concrete error type, while the optional middleware must return an error type that can be converted to the inner service’s error type.