Module stream

Module stream 

Utilities for working across types of streams inside a single connector, to allow the upstream routing table to select the most appropriate type of conenction.

Modules

duplex
A duplex stream suitable for a transport mechanism.
tcp
TCP Stream implementation with better address semantics for servers.
unix
Unix Stream implementation with better address semantics for servers.

Structs

Braid
Dispatching wrapper for potential stream connection types