Struct hyperdriver::stream::duplex::DuplexClient
source · pub struct DuplexClient { /* private fields */ }Expand description
Client for connecting to a duplex server
This is a wrapper around a tokio channel, which is used to send and recieve data between multiple clients and a server.
Implementations
sourceimpl DuplexClient
impl DuplexClient