pub struct DuplexStream { /* private fields */ }Expand description
A duplex stream transports data entirely in memory within the tokio runtime.
Implementations
Sourceimpl DuplexStream
impl DuplexStream
Sourcepub fn new(max_buf_size: usize) -> (Self, Self)
pub fn new(max_buf_size: usize) -> (Self, Self)
Create a new duplex stream pair.
The stream will be created with a buffer, and the name and protocol will be used to
create the connection info. Normally, this method is not needed, an you should prefer
using DuplexClient and DuplexIncoming together to create a client/server pair of duplex streams.