Braid

Struct Braid 

pub struct Braid { /* private fields */ }
Dispatching wrapper for potential stream connection types

Effectively implements enum-dispatch for AsyncRead and AsyncWrite around the stream types which we might use in braid.

This core type is used in the server and client modules, and so is generic over the TLS stream type (which is different for client and server).