Module hyperdriver::client::conn::connection
source · Available on crate feature
client only.Expand description
Connections are responsible for sending and receiving HTTP requests and responses over an arbitrary two-way stream of bytes.
Structs
- An HTTP connection.
Enums
- Error returned when a connection could not be established.
- The URI used for connecting to a server is invalid.
Traits
- A connection to a remote server which can send and recieve HTTP requests/responses.