pub trait FirstAddrExt {
// Provided method
fn first_addr(self) -> FirstAddrResolver<Self>
where Self: Sized { ... }
}Expand description
Extension trait for resolvers that can be converted to a FirstAddrResolver.
Provided Methods
Sourcefn first_addr(self) -> FirstAddrResolver<Self>where
Self: Sized,
fn first_addr(self) -> FirstAddrResolver<Self>where
Self: Sized,
Convert this resolver into a FirstAddrResolver.
This will return the first address resolved by the inner resolver, discarding the rest.