Available on crate feature
client only.Expand description
Protocol describes how http requests and responses are transmitted over a connection.
There are three protocols provided here: HTTP/1.1, HTTP/2, and an automatically negotiated protocol which can be either HTTP/1.1 or HTTP/2 based on the connection protocol and ALPN negotiation.
Modules
- Auto-switching HTTP/1 and HTTP/2 connections.
- HTTP/1 client connections
- HTTP/2 client connections
- mock
mocksMock protocol implementation for testing purposes.
Structs
- A request to establish a connection using a specific HTTP protocol over a given transport.
Enums
- The HTTP protocol to use for a connection.
Traits
- Protocols (like HTTP) define how data is sent and received over a connection.