Struct hyperdriver::discovery::GrpcScheme
source · pub struct GrpcScheme(/* private fields */);Expand description
A scheme for the grpc protocol, which uses the first path component to determine which service to call.
This is how the gRPC protocol works natively.
Implementations