Module hyperdriver::server::conn::tls
source · Available on crate features
server and tls only.Expand description
Implementation of a server side TLS stream on top of tokio_rustls which additionally provides connection information after the handshake has been completed.
Re-exports
pub use self::acceptor::TlsAcceptor;pub use self::info::TlsConnectionInfoLayer;
Modules
- Hyper TLS Acceptor with some support for tracing.
- Tower middleware for collecting TLS connection information after a handshake has been completed.
- sni
sniMiddleware to validate that SNI matches the HOST header using Braid’s connection info
Structs
- A TLS stream, generic over the underlying IO.