Struct hyperdriver::service::AdaptCustomBodyService
source · pub struct AdaptCustomBodyService<BIn, BOut, S> { /* private fields */ }Expand description
Adapt a service to use custom body types internally,
while still accepting and returning Body as the outer body type.
This is useful when interfacing with other libraries which want to bring their
own body types, but you want to use Body as the outer body type and use hyperdriver::Server.
Implementations
sourceimpl<BIn, BOut, S> AdaptCustomBodyService<BIn, BOut, S>
impl<BIn, BOut, S> AdaptCustomBodyService<BIn, BOut, S>