pub struct ExecuteRequest<C: Connection<B> + PoolableConnection, B> { /* private fields */ }Available on crate feature
client only.Expand description
Couples the connection with the http request.
This allows downstream services to access both the request and connection
– they are needed in tandem to send the request. This also means that
middleware can implement tower::Service on tower::Service<ExecuteRequest<C, B>>
to modify the request before it is sent in the context of the connection.
See crate::service::SetHostHeader for an example of a middleware that modifies
the request before it is sent in the context of the connection.
Implementations
Sourceimpl<C: Connection<B> + PoolableConnection, B> ExecuteRequest<C, B>
impl<C: Connection<B> + PoolableConnection, B> ExecuteRequest<C, B>
Sourcepub fn into_parts(self) -> (Pooled<C>, Request<B>)
pub fn into_parts(self) -> (Pooled<C>, Request<B>)
Split the request into its parts.
Sourcepub fn connection(&self) -> &C
pub fn connection(&self) -> &C
A reference to the connection.
Sourcepub fn request_mut(&mut self) -> &mut Request<B>
pub fn request_mut(&mut self) -> &mut Request<B>
A mutable reference to the request.