pub struct ExecuteRequest<C: Connection<B> + PoolableConnection, B, K: Key> { /* private fields */ }Available on crate feature
client only.Expand description
Couples the connection with the http request.
This allows downstream services to access both the request and connection
– they are needed in tandem to send the request. This also means that
middleware can implement tower::Service on tower::Service<ExecuteRequest<C, B>>
to modify the request before it is sent in the context of the connection.
See crate::service::SetHostHeader for an example of a middleware that modifies
the request before it is sent in the context of the connection.
Implementations
sourceimpl<C: Connection<B> + PoolableConnection, B, K: Key> ExecuteRequest<C, B, K>
impl<C: Connection<B> + PoolableConnection, B, K: Key> ExecuteRequest<C, B, K>
sourcepub fn into_parts(self) -> (Pooled<C, K>, Request<B>)
pub fn into_parts(self) -> (Pooled<C, K>, Request<B>)
Split the request into its parts.
sourcepub fn connection(&self) -> &C
pub fn connection(&self) -> &C
A reference to the connection.
sourcepub fn request_mut(&mut self) -> &mut Request<B>
pub fn request_mut(&mut self) -> &mut Request<B>
A mutable reference to the request.