TCP Stream implementation with better address semantics for servers.
This module provides a TcpStream type that wraps tokio::net::TcpStream with
better address semantics for servers. When a server accepts a connection, it
returns the associated SocketAddr along side the stream. On some platforms,
this information is not available after the connection is established via
TcpStream::peer_addr. This module provides a way to retain this information
for the lifetime of the stream.
Structs
- TcpListener
server - A TCP socket server, listening for connections.
- TcpStream
- A TCP Stream, wrapping
tokio::net::TcpStreamwith better address semantics for servers.